@@ -129,7 +129,7 @@ class Connection(abstract.FileDescriptor, tcp._AbortingMixin):
                                data, len(data), ttl, inorder)
         except udt.UDTException as ue:
             if ue[0] == EASYNCRCV:
-                return 0
+                return self.writeSomeData(data, ttl, inorder)
             elif ue[0] == ECONNLOST:
                 return main.CONNECTION_LOST
 
@@ -147,12 +147,16 @@ class Connection(abstract.FileDescriptor, tcp._AbortingMixin):
         if not self.connected or self._writeDisconnected:
             return
         if data:
-            self._tempDataBuffer.append(data)
-            self._tempDataLen += len(data)
-            self._ttl = ttl
-            self._inorder = inorder
-            self._maybePauseProducer()
+            # self._tempDataBuffer.append(data)
+            # self._tempDataLen += len(data)
+            # self._ttl = ttl
+            # self._inorder = inorder
+            # self._maybePauseProducer()
             self.startWriting()
+            l = self.writeSomeData(data, ttl, inorder)
+            if l == main.CONNECTION_LOST:
+                self.loseConnection()
+            
 
     def doWrite(self):
         """
@@ -163,6 +167,7 @@ class Connection(abstract.FileDescriptor, tcp._AbortingMixin):
 
         @see: L{twisted.internet.interfaces.IWriteDescriptor.doWrite}.
         """
+        
         if len(self.dataBuffer) - self.offset < self.SEND_LIMIT:
             # If there is currently less than SEND_LIMIT bytes left to send
             # in the string, extend it with the array data.
@@ -173,6 +178,8 @@ class Connection(abstract.FileDescriptor, tcp._AbortingMixin):
             self._tempDataLen = 0
 
         # Send as much data as you can.
+        if self.dataBuffer == '':
+            return
         if self.offset:
             l = self.writeSomeData(lazyByteSlice(self.dataBuffer, self.offset),
                                    self._ttl, self._inorder)
